***********************************************************************;
* MACRO: THIS MACRO GENERATES INPUT FILES FOR THE RISK FACTOR STUFF **;
***********************************************************************;

%macro GenerateHCCInputData(pct=, year=);

    ** Define what is to be sorted by and what is to define unique index;
    %let rawid=bene_id;
  
*********************************************;
** Carrier Data  ****************************;
*********************************************;

%GenerateCarrierYear(year=&year., pct=&pct.);

data cartemp;
	set cartemp;
	line = _N_;
	keep &rawid. dgns_cd1 dgns_cd2 dgns_cd3 dgns_cd4 dgns_cd5 
	dgns_cd6 dgns_cd7 dgns_cd8 dgns_cd9 dgns_cd10 dgns_cd11 dgns_cd12 line;
run;

proc sort data=cartemp;
	by &rawid. line; 
run;

proc transpose data=cartemp out=longcartemp;
	by &rawid. line;
	var dgns_cd1 dgns_cd2 dgns_cd3 dgns_cd4 dgns_cd5 dgns_cd6 dgns_cd7
	dgns_cd8 dgns_cd9 dgns_cd10 dgns_cd11 dgns_cd12;
run;

data longcartemp;
	set longcartemp;
	rename col1=diag;
	drop _name_ _label_ line;
run;

*********************************************
** Outpatient Data  *************************;
*********************************************;

%GenerateOpClmsYear(year=&year, pct=&pct);

data optemp;
	set optemp;
	line=_N_;
	keep &rawid. dgnscd1 dgnscd2 dgnscd3 dgnscd4 dgnscd5 dgnscd6 dgnscd7 dgnscd8 
	dgnscd9 dgnscd10 dgnscd11 dgnscd12 dgnscd13 dgnscd14 dgnscd15 dgnscd16 dgnscd17 
	dgnscd18 dgnscd19 dgnscd20 dgnscd21 dgnscd22 dgnscd23 dgnscd24 dgnscd25 line;
run;

proc sort data=optemp;
	by &rawid. line;
run;

proc transpose data=optemp out=longoptemp;
	by &rawid. line;
	var dgnscd1 dgnscd2 dgnscd3 dgnscd4 dgnscd5 dgnscd6 dgnscd7 dgnscd8 dgnscd9 dgnscd10
	dgnscd11 dgnscd12 dgnscd13 dgnscd14 dgnscd15 dgnscd16 dgnscd17 dgnscd18 dgnscd19 dgnscd20 
	dgnscd21 dgnscd22 dgnscd23 dgnscd24 dgnscd25 line;
run;

data longoptemp;
	set longoptemp;
	rename col1=diag;
	drop _name_ _label_ line;
run;

*********************************************;
** Medpar Data  **************************;
*********************************************;

%GenerateMedClmsYear(year=&year., pct=&pct.);

data medtemp;
	set medtemp;
	line=_N_;
	keep &rawid. dgnscd1 dgnscd2 dgnscd3 dgnscd4 dgnscd5 dgnscd6 dgnscd7 dgnscd8 dgnscd9 dgnscd10 line;
run;

proc sort data=medtemp; 
	by &rawid. line;
run;

proc transpose data=medtemp out=longmedtemp;
	by &rawid. line;
	var dgnscd1 dgnscd2 dgnscd3 dgnscd4 dgnscd5 dgnscd6 dgnscd7 dgnscd8 dgnscd9 dgnscd10;
run;

data longmedtemp;
	set longmedtemp;
	rename col1=diag;
	drop _name_ _label_ line;
run;

data hcc.hccdgns_&pct._&year.;
	set longmedtemp longoptemp longcartemp;
	if diag ~= "";
run;

proc sort data = hcc.hccdgns_&pct._&year.;
	by &rawid.; 
run;

%mend GenerateHCCInputData;
